SunmiKaliPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • SunmiKaliPlatform
Implementers

Constructors

SunmiKaliPlatform()
Constructs a SunmiKaliPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bindSunmi() Future<String?>
commitPrinterBuffer() Future<String?>
Submete a fila de impressão atual e mantém o modo transação ativo.
commitPrinterBufferWithCallback() Future<String?>
Submete a fila e aguarda o resultado real da impressora (resolve apenas em onPrintResult).
enterPrinterBuffer(bool clean) Future<String?>
Inicia o modo de impressão por transação. clean = true limpa qualquer conteúdo previamente bufferizado. Não suportado no Sunmi V1.
exitPrinterBuffer(bool commit) Future<String?>
Encerra o modo transação. Se commit = true, imprime conteúdo pendente.
exitPrinterBufferWithCallback(bool commit) Future<String?>
Encerra o modo transação e aguarda o resultado real da impressora.
getPlatformVersion() Future<String?>
getPrinterModel() Future<String?>
getPrinterSerialNo() Future<String?>
labelLocate() Future<String?>
labelOutput() Future<String?>
lineWrap(int linesCount) Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printerInit() Future<String?>
printImage(Uint8List? bytes) Future<String?>
printImageController(WidgetsToImageController controller, int count) Future<String?>
printText(String? text) Future<String?>
setAlignment(int position) Future<String?>
toString() String
A string representation of this object.
inherited
unBindSunmi() Future<String?>
updatePrinterState() Future<int?>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance SunmiKaliPlatform
The default instance of SunmiKaliPlatform to use.
getter/setter pair